package com.zehong.system.service.impl.track;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.track.TProductDrawingMapper;
import com.zehong.system.domain.track.TProductDrawing;
import com.zehong.system.service.track.ITProductDrawingService;

/**
 * 图纸Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-21
 */
@Service
public class TProductDrawingServiceImpl implements ITProductDrawingService 
{
    @Autowired
    private TProductDrawingMapper tProductDrawingMapper;

    /**
     * 查询图纸
     * 
     * @param id 图纸ID
     * @return 图纸
     */
    @Override
    public TProductDrawing selectTProductDrawingById(Long id)
    {
        return tProductDrawingMapper.selectTProductDrawingById(id);
    }

    /**
     * 查询图纸列表
     * 
     * @param tProductDrawing 图纸
     * @return 图纸
     */
    @Override
    public List<TProductDrawing> selectTProductDrawingList(TProductDrawing tProductDrawing)
    {
        return tProductDrawingMapper.selectTProductDrawingList(tProductDrawing);
    }

    /**
     * 新增图纸
     * 
     * @param tProductDrawing 图纸
     * @return 结果
     */
    @Override
    public int insertTProductDrawing(TProductDrawing tProductDrawing)
    {
        tProductDrawing.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        tProductDrawing.setCreateTime(DateUtils.getNowDate());
        return tProductDrawingMapper.insertTProductDrawing(tProductDrawing);
    }

    /**
     * 修改图纸
     * 
     * @param tProductDrawing 图纸
     * @return 结果
     */
    @Override
    public int updateTProductDrawing(TProductDrawing tProductDrawing)
    {
        return tProductDrawingMapper.updateTProductDrawing(tProductDrawing);
    }

    /**
     * 批量删除图纸
     * 
     * @param ids 需要删除的图纸ID
     * @return 结果
     */
    @Override
    public int deleteTProductDrawingByIds(Long[] ids)
    {
        return tProductDrawingMapper.deleteTProductDrawingByIds(ids);
    }

    /**
     * 删除图纸信息
     * 
     * @param id 图纸ID
     * @return 结果
     */
    @Override
    public int deleteTProductDrawingById(Long id)
    {
        return tProductDrawingMapper.deleteTProductDrawingById(id);
    }

    /**
     * 根据产品主键获取图纸信息
     * @param drawing
     * @return
     */
    @Override
    public List<TProductDrawing> getDrawInfoByDeviceId(TProductDrawing drawing){
        return tProductDrawingMapper.getDrawInfoByDeviceId(drawing);
    }

}
