package com.zehong.system.service.track;

import java.util.List;

import com.zehong.system.domain.track.TProductInspectDetail;
import com.zehong.system.domain.track.TProductStore;
import com.zehong.system.domain.vo.HouseVo;

/**
 * 配件Service接口
 * 
 * @author zehong
 * @date 2024-08-22
 */
public interface ITProductStoreService 
{
    /**
     * 查询配件
     * 
     * @param id 配件ID
     * @return 配件
     */
    public TProductStore selectTProductStoreById(Long id);

    /**
     * 查询配件列表
     * 
     * @param tProductStore 配件
     * @return 配件集合
     */
    public List<TProductStore> selectTProductStoreList(TProductStore tProductStore);

    /**
     * 新增配件
     * 
     * @param tProductStore 配件
     * @return 结果
     */
    public int insertTProductStore(TProductStore tProductStore);

    /**
     * 修改配件
     * 
     * @param tProductStore 配件
     * @return 结果
     */
    public int updateTProductStore(TProductStore tProductStore);

    /**
     * 批量删除配件
     * 
     * @param ids 需要删除的配件ID
     * @return 结果
     */
    public int deleteTProductStoreByIds(Long[] ids);

    /**
     * 删除配件信息
     * 
     * @param id 配件ID
     * @return 结果
     */
    public int deleteTProductStoreById(Long id);

    /**
     * 配件批量入库
     * @param storeInfo 配件信息
     * @param isAddLog 是否记录日志
     * @param type 操作类型
     * @return
     */
    int computeStock(List<HouseVo> storeInfo,boolean isAddLog,String type);

    /**
     * 根据产品主键获取配件信息
     * @param store
     * @return
     */
    List<TProductStore> getStoreInfoByDeviceId(TProductStore store);

}
